/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_SEC_STRUCT_PREDICT_PLUGIN_H_
#define _U2_SEC_STRUCT_PREDICT_PLUGIN_H_

#include <U2Core/PluginModel.h>
#include <U2Core/AnnotationData.h>

namespace U2 {

class SecStructPredictPlugin : public Plugin {
	Q_OBJECT
public:
    SecStructPredictPlugin();
	~SecStructPredictPlugin();

};


} //namespace

#endif // _U2_SEC_STRUCT_PREDICT_PLUGIN_H_


